@@ -15,6 +15,15 @@ fn it_can_be_created_from_a_string() {
 
     assert_eq!(String::from(comment), String::from("# Example Comment"));
 }
+#[test]
+fn it_can_tell_me_if_a_char_is_a_legal_comment_char() {
+    assert!(Comment::is_legal_comment_char('#'));
+}
+
+#[test]
+fn it_can_tell_me_if_a_char_is_not_legal_comment_char() {
+    assert!(!Comment::is_legal_comment_char('?'));
+}
 
 #[test]
 fn it_can_append_another_comment_fragment() {
